.. _newline_indices-name:

!!!!!!!!!!!!!!!
newline_indices
!!!!!!!!!!!!!!!

.. meta::
  :keywords: newline_indices,find,index,of,all,the,newlines,in,a,string,prototype,data,results,newline_list

.. index:: newline_indices, find, index, all, newlines, in, string

.. _newline_indices-title:

Find index of all the newlines in a string
##########################################

.. contents::
  :local:

.. index:: prototype

.. _newline_indices@Prototype:

Prototype
*********

.. literalinclude:: ../../xrst/newline_indices.py
  :lines: 33-34,43-47
  :language: py

.. index:: data

.. _newline_indices@data:

data
****
The string we are searching for newlines.

.. index:: results

.. _newline_indices@Results:

Results
*******

.. index:: newline_list

.. _newline_indices@newline_list:

newline_list
************
The return newline_list is the list of indices in data that
represent all of the newlines; i.e. '\n'.
